package com.persagy.dc.define.client;

import com.persagy.dc.basic.config.DigitalFeignConfig;
import com.persagy.dc.basic.model.QueryCriteria;
import com.persagy.dc.common.model.response.CommonResult;
import com.persagy.dc.common.model.response.PageList;
import com.persagy.dc.define.entity.ObjectTypeDefine;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 文件管理Client
 * @author Charlie Yu
 * @date 2021-05-15
 */
@FeignClient(name = "dc-digital", configuration = DigitalFeignConfig.class)
public interface DigitalDefineClient {

    /**
     * 查询类型定义
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param criteria 查询条件
     * @return 类型定义
     */
    @PostMapping("/define/type/query")
    CommonResult<PageList<ObjectTypeDefine>> queryObjectType(
            @RequestParam("groupCode") String groupCode,
            @RequestParam("projectId") String projectId,
            @RequestParam("appId") String appId,
            @RequestParam("userId") String userId,
            @RequestBody QueryCriteria criteria);
}
